@@ -1,6 +1,6 @@
 from typing import Optional, List
 
-from pyspark.sql.types import StructType, StructField, ArrayType, DataType
+from pyspark.sql.types import StructType, StructField, ArrayType, DataType, NullType
 
 
 class SchemaCompareError:
@@ -18,13 +18,14 @@ class SchemaCompareError:
 
     def __str__(self) -> str:
         return (
-            (("[" + self.column + "]") if self.column else "")
+            (("column: [" + self.column + "]") if self.column else "")
+            + "\n"
             + self.error
             + "\n"
-            + "source_schema:"
+            + "source_schema: "
             + str(self.source_schema)
             + "\n"
-            + "desired_schema:"
+            + "desired_schema: "
             + str(self.desired_schema)
             + "\n"
         )
@@ -45,11 +46,13 @@ class SchemaComparer:
         source_schema: DataType,
         desired_schema: StructType,
     ) -> List[SchemaCompareError]:
+        if isinstance(source_schema, NullType):
+            return []
         if not isinstance(source_schema, StructType):
             return [
                 SchemaCompareError(
                     column=parent_column_name,
-                    error=f"ERROR: Type of {parent_column_name} does not match.",
+                    error=f"ERROR: Type of {parent_column_name} does not match with struct.",
                     source_schema=source_schema,
                     desired_schema=desired_schema,
                 )
@@ -94,11 +97,14 @@ class SchemaComparer:
         source_schema: DataType,
         desired_schema: ArrayType,
     ) -> List[SchemaCompareError]:
+        if isinstance(source_schema, NullType):
+            return []
+
         if not isinstance(source_schema, ArrayType):
             return [
                 SchemaCompareError(
                     column=parent_column_name,
-                    error=f"ERROR: Type of {parent_column_name} does not match.",
+                    error=f"ERROR: Type of {parent_column_name} does not match with array.",
                     source_schema=source_schema,
                     desired_schema=desired_schema,
                 )
@@ -116,12 +122,15 @@ class SchemaComparer:
         source_schema: DataType,
         desired_schema: DataType,
     ) -> List[SchemaCompareError]:
+        if isinstance(source_schema, NullType):
+            return []
+
         # compare the two
         if desired_schema != source_schema:
             return [
                 SchemaCompareError(
                     column=parent_column_name,
-                    error=f"ERROR: Type of {parent_column_name} does not match.",
+                    error=f"ERROR: Type of {parent_column_name} does not match with simple type.",
                     source_schema=source_schema,
                     desired_schema=desired_schema,
                 )
