@@ -3,23 +3,29 @@ from pathlib import Path
 from shutil import rmtree
 
 import pytest
+
 # noinspection PyProtectedMember
 from _pytest._code import ExceptionInfo
 from pyspark.sql import SparkSession, DataFrame
 from pyspark.sql.functions import lit
 
-from spark_data_frame_comparer.spark_data_frame_comparer import assert_compare_data_frames
-from spark_data_frame_comparer.spark_data_frame_comparer_exception import SparkDataFrameComparerException, ExceptionType
+from spark_data_frame_comparer.spark_data_frame_comparer import (
+    assert_compare_data_frames,
+)
+from spark_data_frame_comparer.spark_data_frame_comparer_exception import (
+    SparkDataFrameComparerException,
+    ExceptionType,
+)
 from tests.conftest import clean_spark_session
 
 
 def test_can_compare_simple_fail(spark_session: SparkSession) -> None:
     # Arrange
     clean_spark_session(spark_session)
-    data_dir: Path = Path(__file__).parent.joinpath('./')
+    data_dir: Path = Path(__file__).parent.joinpath("./")
     test_file_path: str = f"{data_dir.joinpath('input/complex.json')}"
 
-    temp_folder = data_dir.joinpath('./temp')
+    temp_folder = data_dir.joinpath("./temp")
     if path.isdir(temp_folder):
         rmtree(temp_folder)
     mkdir(temp_folder)
@@ -41,10 +47,8 @@ def test_can_compare_simple_fail(spark_session: SparkSession) -> None:
             expected_path=test_file_path,
             result_path=result_path,
             temp_folder=temp_folder,
-            func_path_modifier=lambda x: x
+            func_path_modifier=lambda x: x,
         )
 
     assert exc_info.value.exception_type == ExceptionType.SchemaMismatch
-    assert not path.exists(
-        data_dir.joinpath("temp/compare_complex.json.command")
-    )
+    assert not path.exists(data_dir.joinpath("temp/compare_complex.json.command"))
